@@ -2,6 +2,7 @@ from typing import Dict, Any, Callable, Awaitable, List, Optional, Union
 import base64
 import httpx
 import os
+from urllib.parse import urlparse
 from pydantic import ValidationError
 from .agent_config import AgentConfig
 from .agent_identity import AgentIdentity
@@ -29,11 +30,13 @@ class Agent:
             self.active_registry = registry
         else:
             self.active_registry = self.registries['internal']
+        self.registry = self.active_registry
 
     def use_registry(self, name: str) -> "Agent":
         if name not in self.registries:
             raise ValueError(f"Registry with name '{name}' not found.")
         self.active_registry = self.registries[name]
+        self.registry = self.active_registry
         return self
 
     def add_registry(self, registry: AgentRegistry) -> "Agent":
@@ -56,7 +59,7 @@ class Agent:
             raise ValueError(
                 f"Capability '{capability_id}' not defined in agent configuration."
             )
-        
+
         def decorator(func: CapabilityHandler):
             self._capability_handlers[capability_id] = func
             return func
@@ -169,6 +172,12 @@ class Agent:
     def endpoint(self) -> str:
         return self.config.endpoint
 
+    def port(self) -> int:
+        return self.config.port
+
+    def host(self) -> str:
+        return self.config.host
+
     async def send_task(
         self, to_agent_id: str, capability: str, params: dict, task_id: str = None
     ) -> dict:
